pept.tracking API documentation

# Module `pept.tracking`

Source code

    #!/usr/bin/env python3
    # -*- coding: utf-8 -*-

    # File   : __init__.py
    # License: License: GNU v3.0
    # Author : Andrei Leonard Nicusan <a.l.nicusan@bham.ac.uk>
    # Date   : 21.08.2019

    from    .   import  peptml
    from    .   import  birmingham_method

    __all__ = [
        'peptml',
        'birmingham_method'
    ]

    __author__ =        "Andrei Leonard Nicusan, Sam Manger"
    __credits__ =       ["Andrei Leonard Nicusan", "Kit Windows-Yule", "Sam Manger"]
    __license__ =       "GNU v3.0"
    __version__ =       "0.1"
    __maintainer__ =    "Andrei Leonard Nicusan"
    __email__ =         "a.l.nicusan@bham.ac.uk"
    __status__ =        "Development"

## Sub-modules

`pept.tracking.birmingham_method`
`pept.tracking.peptml`
`pept.tracking.trajectory_separation`